@@ -137,7 +137,7 @@ class lvm_model:
     global LVS_HAS_ALL_OPTION
     global LVS_HAS_MIRROR_OPTIONS
     
-    out, status = execWithCaptureStatus(LVM_BIN_PATH, [LVM_BIN_PATH, 'lvs', '--all'])
+    out, status = execWithCaptureStatus(LVM_BIN_PATH, [LVM_BIN_PATH, 'lvs', '--config', "'log{command_names=0}'", '--all'])
     if status == 0:
       LVS_HAS_ALL_OPTION = True
     LVS_HAS_MIRROR_OPTIONS = LVS_HAS_ALL_OPTION
@@ -318,6 +318,8 @@ class lvm_model:
     arglist = list()
     arglist.append(LVM_BIN_PATH)
     arglist.append("pvs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append("--nosuffix")
     arglist.append("--noheadings")
     arglist.append("--units")
@@ -387,6 +389,8 @@ class lvm_model:
     arglist = list()
     arglist.append(LVM_BIN_PATH)
     arglist.append("vgs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append("--nosuffix")
     arglist.append("--noheadings")
     arglist.append("--units")
@@ -454,6 +458,8 @@ class lvm_model:
     arglist = list()
     arglist.append(LVM_BIN_PATH)
     arglist.append("lvs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")    
     arglist.append("--nosuffix")
     arglist.append("--noheadings")
     arglist.append("--units")
@@ -572,9 +578,14 @@ class lvm_model:
           if lv.is_mirrored():
             # replace tmp lvs with real one
             # log
-            log_lv = vg.get_lvs()[lv.get_mirror_log()]
-            vg.get_lvs().pop(log_lv.get_name()) # remove log_lv from vg
-            lv.set_mirror_log(log_lv)
+            #log_lv = vg.get_lvs()[lv.get_mirror_log()]
+            #vg.get_lvs().pop(log_lv.get_name()) # remove log_lv from vg
+            #lv.set_mirror_log(log_lv)
+            mlog = lv.get_mirror_log()
+            if mlog:
+                log_lv = vg.get_lvs()[mlog]
+                vg.get_lvs().pop(log_lv.get_name()) # remove log_lv from vg
+                lv.set_mirror_log(log_lv)
             # images
             segment = lv.get_segments()[0]
             images_tmp = segment.get_images()[:] # copy
@@ -650,6 +661,8 @@ class lvm_model:
     arglist = list()
     arglist.append(LVM_BIN_PATH)
     arglist.append("lvs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append("--noheadings")
     arglist.append("-o")
     arglist.append('move_pv')
@@ -673,6 +686,8 @@ class lvm_model:
   def __reload_logical_volumes_paths(self):
     self.__lvs_paths = {}
     arglist = [LVDISPLAY_BIN_PATH] #lvs does not give path info
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append('-c')
     if LVS_HAS_ALL_OPTION:
       arglist.append('-a')
@@ -716,6 +731,8 @@ class lvm_model:
   def __set_VGs_props(self):
     arglist = [LVM_BIN_PATH]
     arglist.append("vgs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append("--nosuffix")
     arglist.append("--noheadings")
     #arglist.append("--units")
@@ -857,6 +874,8 @@ class lvm_model:
     arglist = list()
     arglist.append(LVM_BIN_PATH)
     arglist.append("pvs")
+    arglist.append("--config")
+    arglist.append("'log{command_names=0}'")
     arglist.append("--noheadings")
     arglist.append("--separator")
     arglist.append(",")
@@ -864,7 +883,23 @@ class lvm_model:
     arglist.append(PVS_OPTION_STRING)
     pvs_output = execWithCapture(LVM_BIN_PATH,arglist)
     for pv in self.__PVs:
+      prop = []
+      for path in pv.get_paths():
+        wwid = self.__get_wwid(path)
+        if wwid != None and wwid != "":
+          prop.append("SCSI WWID: ")
+          prop.append(wwid)
+        
+      pv.set_properties(prop)
       pv.set_properties(self.__get_data_for_PV(pv, pvs_output))
+
+  def __get_wwid(self, device):
+    try:
+      output = execWithCapture(SCSIID_BIN_PATH, ["--page=0x83", "--whitelisted", "--device=" + device]);
+      return output
+    except Exception:
+      return None    
+      
   def __get_data_for_PV(self, pv, pvs_output):
     # anything that is in, place to the end
     end = pv.get_properties()
