@@ -470,12 +470,13 @@ class DisplayView:
             # set up mirroring log
             if lv.is_mirrored():
                 log_lv = lv.get_mirror_log()
-                for seg2 in log_lv.get_segments():
-                    # log should have linear mapping only
-                    extent = seg2.get_extent_block()
-                    subcyl = Subcylinder(self.lv_cyl_gen, 1, 0, False, extent.get_start_size()[1])
-                    lv_cyls_dir[extent] = subcyl
-                    cyl.children.append(subcyl)
+                if log_lv:
+                    for seg2 in log_lv.get_segments():
+                        # log should have linear mapping only
+                        extent = seg2.get_extent_block()
+                        subcyl = Subcylinder(self.lv_cyl_gen, 1, 0, False, extent.get_start_size()[1])
+                        lv_cyls_dir[extent] = subcyl
+                        cyl.children.append(subcyl)
             
             # set up helper display
             cyl.add_object(CYL_ID_VOLUME, lv)
